dnl ######################################################################
dnl
dnl File:       petsc.m4
dnl
dnl Purpose:    Determine if PETSc is installed.
dnl
dnl Variables defined in AC_SUBST
dnl   Basics:			Include Directories:
dnl     PETSC_DIR		  PETSC_INCDIR
dnl     PETSC_ARCH		  PETSC_INCDIR_ARCH
dnl   Library:			Library Info:
dnl     PETSC_LIB		  PETSC_LIBDIR
dnl     PETSC_LIB_CONTRIB	  PETSC_LIB_TYPE
dnl     PETSC_LIB_DM		  PETSC_LIB_STATUS
dnl     PETSC_LIB_KSP           Complete Substitutions
dnl     PETSC_LIB_MAT		  PETSC_INC
dnl     PETSC_LIB_SNES		  PETSC_LIBS
dnl     PETSC_LIB_TS
dnl     PETSC_LIB_VEC
dnl
dnl Version:    $Id: petsc.m4 2185 2007-02-19 23:34:58Z sizemore $
dnl
dnl Copyright Tech-X Corporation, 2001-2005.  Redistribution allowed
dnl provided this copyright statement remains intact.
dnl
dnl ######################################################################

dnl ----------------------------------------------------------------------
dnl Begin by saving all variables from the input line
dnl ----------------------------------------------------------------------

if test -n "$PETSC_DIR"; 		then SAVE_PETSC_DIR="$PETSC_DIR"; 			fi
if test -n "$PETSC_ARCH"; 		then SAVE_PETSC_ARCH="$PETSC_ARCH"; 			fi
if test -n "$PETSC_INCDIR"; 		then SAVE_PETSC_INCDIR="$PETSC_INCDIR"; 		fi
if test -n "$PETSC_INCDIR_ARCH"; 	then SAVE_PETSC_INCDIR_ARCH="$PETSC_INCDIR_ARCH"; 	fi
if test -n "$PETSC_LIBDIR";		then SAVE_PETSC_LIBDIR="$PETSC_LIBDIR";			fi
if test -n "$PETSC_LIB";		then SAVE_PETSC_LIB="$PETSC_LIB";			fi
if test -n "$PETSC_LIB_CONTRIB";	then SAVE_PETSC_LIB_CONTRIB="$PETSC_LIB_CONTRIB";	fi
if test -n "$PETSC_LIB_DM";		then SAVE_PETSC_LIB_DM="$PETSC_LIB_DM";			fi
if test -n "$PETSC_LIB_KSP";		then SAVE_PETSC_LIB_KSP="$PETSC_LIB_KSP";		fi
if test -n "$PETSC_LIB_MAT";		then SAVE_PETSC_LIB_MAT="$PETSC_LIB_MAT";		fi
if test -n "$PETSC_LIB_SNES";		then SAVE_PETSC_LIB_SNES="$PETSC_LIB_SNES";		fi
if test -n "$PETSC_LIB_TS";		then SAVE_PETSC_LIB_TS="$PETSC_LIB_TS";			fi
if test -n "$PETSC_LIB_VEC";		then SAVE_PETSC_LIB_VEC="$PETSC_LIB_VEC";		fi

dnl ----------------------------------------------------------------------
dnl Locate the installation directory of PETSc
dnl ----------------------------------------------------------------------

AC_MSG_CHECKING([for PETSc install dir])

AC_ARG_WITH(
  [PETSC_DIR],
  [  --with-PETSC_DIR=<dir>          Full path to the PETSc installation directory
	Default: ${PETSC_DIR}],
  [PETSC_DIR="${withval}"])

dnl Check validity of directory
temp=`ls $PETSC_DIR`
if test -z "$temp"; then
  AC_MSG_RESULT([not found])
  AC_MSG_ERROR([Directory $PETSC_DIR does not exist])
else
  AC_MSG_RESULT([$PETSC_DIR])
fi

dnl ----------------------------------------------------------------------
dnl Establish the architecture of PETSc that should be used
dnl ----------------------------------------------------------------------

AC_MSG_CHECKING([for PETSc architecture])

AC_ARG_WITH(
  [PETSC_ARCH],
  [  --with-PETSC_ARCH=<arch>        Architecture of PETSc to be used
	Default: ${PETSC_ARCH}],
  [PETSC_ARCH="${withval}"])

dnl Check validity of architecture specified
temp=`ls $PETSC_DIR/lib/$PETSC_ARCH`
if test -z "$temp"; then
  AC_MSG_RESULT([not found])
  AC_MSG_ERROR([Architecture $PETSC_ARCH does not exist])
else
  AC_MSG_RESULT([$PETSC_ARCH])
fi

dnl ----------------------------------------------------------------------
dnl Locate key include files from standard and user-defined locations
dnl ----------------------------------------------------------------------

dnl Find and validate petsc.h
PETSC_INCDIR_PATH=$SAVE_PETSC_INCDIR:$PETSC_DIR/include

AC_ARG_WITH(
  [PETSC_INCDIR],
  [  --with-PETSC_INCDIR=<dir>       Full path to the PETSc includes directory
	Default: ${PETSC_DIR}/include],
  [PETSC_INCDIR="${withval}"])
if test -n "$PETSC_INCDIR"; then PETSC_INCDIR_PATH=$PETSC_INCDIR:$PETSC_INCDIR_PATH; fi

AC_PATH_PROGS([PETSC_INCDIR],[petsc.h],[],[$PETSC_INCDIR_PATH])
if test -z "$PETSC_INCDIR"; then
  AC_MSG_ERROR([Header petsc.h does not exist])
else
  PETSC_INCDIR=`dirname $PETSC_INCDIR`
fi

dnl Find and validate petscconf.h
PETSC_INCDIR_ARCH_PATH=$SAVE_PETSC_INCDIR_ARCH:$PETSC_DIR/bmake/$PETSC_ARCH

AC_ARG_WITH(
  [PETSC_INCDIR_ARCH],
  [  --with-PETSC_INCDIR_ARCH=<dir>  Full path to the architecture dependent includes
	Default: ${PETSC_DIR}/bmake/${PETSC_ARCH}],
  [PETSC_INCDIR_ARCH="${withval}"])
if test -n "$PETSC_INCDIR_ARCH"; then PETSC_INCDIR_ARCH_PATH=$PETSC_INCDIR_ARCH:$PETSC_INCDIR_ARCH_PATH; fi

AC_PATH_PROGS([PETSC_INCDIR_ARCH],[petscconf.h],[],[$PETSC_INCDIR_ARCH_PATH])
if test -z "$PETSC_INCDIR_ARCH"; then 
  AC_MSG_ERROR([Header petscconf.h does not exist])
else
  PETSC_INCDIR_ARCH=`dirname $PETSC_INCDIR_ARCH`
fi

dnl Defnie PETSC_INC for single variable substitution

PETSC_INC="-I"$PETSC_INCDIR" -I"$PETSC_INCDIR_ARCH

dnl ----------------------------------------------------------------------
dnl Establish and and locate static or dynamic libraries
dnl ----------------------------------------------------------------------

PETSC_LIBDIR_PATH=$SAVE_PETSC_LIBDIR:$PETSC_DIR/lib/$PETSC_ARCH

AC_ARG_WITH(
  [PETSC_LIBDIR],
  [  --with-PETSC_LIBDIR=<dir>       Full path to the compiled PETSc libraries
	Default: ${PETSC_DIR}/lib/${PETSC_ARCH}],
  [PETSC_LIBDIR="${withval}"])
if test -n "$PETSC_LIBDIR"; then PETSC_LIBDIR_PATH=$PETSC_LIBDIR:$PETSC_LIBDIR_PATH; fi

dnl Default flags for searching static or dynamic librarie
use_static=0
use_dynamic=1
force_static=0
force_dynamic=0

dnl Set search flags according to options passed
AC_ARG_ENABLE(
  [PETSC_USE_STATIC],
  [  --enable-PETSC_USE_STATIC       Search for static PETSc libraries before dynamic ones
	Default: no],
  [if test ${enableval} = "yes"; then use_static=1; use_dynamic=0; fi])

AC_ARG_ENABLE(
  [PETSC_FORCE_STATIC],
  [  --enable-PETSC_FORCE_STATIC     Search for static PETSc libraries only, skip dynamic
	Default: no],
  [if test ${enableval} = "yes"; then use_static=1; force_static=1; use_dynamic=0; fi])

AC_ARG_ENABLE(
  [PETSC_USE_DYNAMIC],
  [  --enable-PETSC_USE_DYNAMIC      Search for dynamic PETSc libraries before static ones
	Default: yes],
  [if test ${enableval} = "yes"; then
    if test $use_static -eq 1; then 
      AC_MSG_WARN([Conflicting options given, using dynamic library options])
    fi
    use_static=0; force_static=0; use_dynamic=1
  fi])

AC_ARG_ENABLE(
  [PETSC_FORCE_DYNAMIC],
  [  --enable-PETSC_FORCE_DYNAMIC    Search for dynamic PETSc libraries only, skip static
	Default: no],
  [if test ${enableval} = "yes"; then
    if test $use_static -eq 1; then 
      AC_MSG_WARN([Conflicting options given, using dynamic library options])
    fi
    use_static=0; force_static=0; use_dynamic=1; force_dynamic=1
  fi])

dnl Sanity check, in case both library checks are disabled, reset defaults and warn
if test $use_static -eq 0 -a $use_dynamic -eq 0; then
  AC_MSG_WARN([Both library checks were disabled, reverting to defaults])
  use_static=0; force_static=0; use_dynamic=1; force_dynamic=0
fi

dnl Set all variables that have been supplied via user input

dnl libpetsc.so(a)
AC_ARG_WITH(
  [PETSC_LIB],
  [  --with-PETSC_LIB                Full pathname to the libpetsc library
	Default: ${PETSC_DIR}/lib/${PETSC_ARCH}/libpetsc.so(a)],
  [PETSC_LIB="${withval}"])
if test -n "$PETSC_LIB"; then temp=`echo "$PETSC_LIB" | grep "^/"`; else temp=""; fi
if test -n "$temp"; then
  temp=`ls $PETSC_LIB`
  if test -z "$temp"; then AC_MSG_ERROR([File $PETSC_LIB does not exist]); fi
  temp1=`ls $PETSC_LIB | grep "\.so$"`
  temp2=`ls $PETSC_LIB | grep "\.a$"`
  if test -n "$temp1"; then 
    use_static=0; use_dynamic=1; force_dynamic=1
  elif test -n "$temp2"; then
    use_static=1; force_static=1; use_dynamic=0
  else
    AC_MSG_ERROR([Unknown library file format: $PETSC_LIB])
  fi
  if test force_static -eq force_dynamic; then AC_MSG_ERROR([Mixing static and dynamic PETSc libraries]); fi
  PETSC_LIBDIR=`dirname $PETSC_LIB`
  PETSC_LIBDIR_PATH=$PETSC_LIBDIR_PATH:$PETSC_LIBDIR
  search_petsc_lib=0
else
  search_petsc_lib=1
fi

dnl libpetsccontrib.so(a)
AC_ARG_WITH(
  [PETSC_LIB_CONTRIB],
  [  --with-PETSC_LIB_CONTRIB        Full pathname to the libpetsccontrib library
	Default: ${PETSC_DIR}/lib/${PETSC_ARCH}/libpetsccontrib.so(a)],
  [PETSC_LIB_CONTRIB="${withval}"])
if test -n "$PETSC_LIB_CONTRIB"; then temp=`echo "$PETSC_LIB_CONTRIB" | grep "^/"`; else temp=""; fi
if test -n "$temp"; then
  temp=`ls $PETSC_LIB_CONTRIB`
  if test -z "$temp"; then AC_MSG_ERROR([File $PETSC_LIB_CONTRIB does not exist]); fi
  temp1=`ls $PETSC_LIB_CONTRIB | grep "\.so$"`
  temp2=`ls $PETSC_LIB_CONTRIB | grep "\.a$"`
  if test -n "$temp1"; then 
    use_static=0; use_dynamic=1; force_dynamic=1
  elif test -n "$temp2"; then
    use_static=1; force_static=1; use_dynamic=0
  else
    AC_MSG_ERROR([Unknown library file format: $PETSC_LIB_CONTRIB])
  fi
  if test force_static -eq force_dynamic; then AC_MSG_ERROR([Mixing static and dynamic PETSc libraries]); fi
  search_petsc_lib_contrib=0
else
  search_petsc_lib_contrib=1
fi

dnl libpetscdm.so(a)
AC_ARG_WITH(
  [PETSC_LIB_DM],
  [  --with-PETSC_LIB_DM             Full pathname to the libpetscdm library
	Default: ${PETSC_DIR}/lib/${PETSC_ARCH}/libpetscdm.so(a)],
  [PETSC_LIB_DM="${withval}"])
if test -n "$PETSC_LIB_DM"; then temp=`echo "$PETSC_LIB_DM" | grep "^/"`; else temp=""; fi
if test -n "$temp"; then
  temp=`ls $PETSC_LIB_DM`
  if test -z "$temp"; then AC_MSG_ERROR([File $PETSC_LIB_DM does not exist]); fi
  temp1=`ls $PETSC_LIB_DM | grep "\.so$"`
  temp2=`ls $PETSC_LIB_DM | grep "\.a$"`
  if test -n "$temp1"; then 
    use_static=0; use_dynamic=1; force_dynamic=1
  elif test -n "$temp2"; then
    use_static=1; force_static=1; use_dynamic=0
  else
    AC_MSG_ERROR([Unknown library file format: $PETSC_LIB_DM])
  fi
  if test force_static -eq force_dynamic; then AC_MSG_ERROR([Mixing static and dynamic PETSc libraries]); fi
  search_petsc_lib_dm=0
else
  search_petsc_lib_dm=1
fi

dnl libpetscksp.so(a)
AC_ARG_WITH(
  [PETSC_LIB_KSP],
  [  --with-PETSC_LIB_KSP            Full pathname to the libpetscksp library
	Default: ${PETSC_DIR}/lib/${PETSC_ARCH}/libpetscksp.so(a)],
  [PETSC_LIB_KSP="${withval}"])
if test -n "$PETSC_LIB_KSP"; then temp=`echo "$PETSC_LIB_KSP" | grep "^/"`; else temp=""; fi
if test -n "$temp"; then
  temp=`ls $PETSC_LIB_KSP`
  if test -z "$temp"; then AC_MSG_ERROR([File $PETSC_LIB_KSP does not exist]); fi
  temp1=`ls $PETSC_LIB_KSP | grep "\.so$"`
  temp2=`ls $PETSC_LIB_KSP | grep "\.a$"`
  if test -n "$temp1"; then 
    use_static=0; use_dynamic=1; force_dynamic=1
  elif test -n "$temp2"; then
    use_static=1; force_static=1; use_dynamic=0
  else
    AC_MSG_ERROR([Unknown library file format: $PETSC_LIB_KSP])
  fi
  if test force_static -eq force_dynamic; then AC_MSG_ERROR([Mixing static and dynamic PETSc libraries]); fi
  search_petsc_lib_ksp=0
else
  search_petsc_lib_ksp=1
fi

dnl libpetscmat.so(a)
AC_ARG_WITH(
  [PETSC_LIB_MAT],
  [  --with-PETSC_LIB_MAT            Full pathname to the libpetscmat library
	Default: ${PETSC_DIR}/lib/${PETSC_ARCH}/libpetscmat.so(a)],
  [PETSC_LIB_MAT="${withval}"])
if test -n "$PETSC_LIB_MAT"; then temp=`echo "$PETSC_LIB_MAT" | grep "^/"`; else temp=""; fi
if test -n "$temp"; then
  temp=`ls $PETSC_LIB_MAT`
  if test -z "$temp"; then AC_MSG_ERROR([File $PETSC_LIB_MAT does not exist]); fi
  temp1=`ls $PETSC_LIB_MAT | grep "\.so$"`
  temp2=`ls $PETSC_LIB_MAT | grep "\.a$"`
  if test -n "$temp1"; then 
    use_static=0; use_dynamic=1; force_dynamic=1
  elif test -n "$temp2"; then
    use_static=1; force_static=1; use_dynamic=0
  else
    AC_MSG_ERROR([Unknown library file format: $PETSC_LIB_MAT])
  fi
  if test force_static -eq force_dynamic; then AC_MSG_ERROR([Mixing static and dynamic PETSc libraries]); fi
  search_petsc_lib_mat=0
else
  search_petsc_lib_mat=1
fi

dnl libpetscsnes.so(a)
AC_ARG_WITH(
  [PETSC_LIB_SNES],
  [  --with-PETSC_LIB_SNES           Full pathname to the libpetscsnes library
	Default: ${PETSC_DIR}/lib/${PETSC_ARCH}/libpetscsnes.so(a)],
  [PETSC_LIB_SNES="${withval}"])
if test -n "$PETSC_LIB_SNES"; then temp=`echo "$PETSC_LIB_SNES" | grep "^/"`; else temp=""; fi
if test -n "$temp"; then
  temp=`ls $PETSC_LIB_SNES`
  if test -z "$temp"; then AC_MSG_ERROR([File $PETSC_LIB_SNES does not exist]); fi
  temp1=`ls $PETSC_LIB_SNES | grep "\.so$"`
  temp2=`ls $PETSC_LIB_SNES | grep "\.a$"`
  if test -n "$temp1"; then 
    use_static=0; use_dynamic=1; force_dynamic=1
  elif test -n "$temp2"; then
    use_static=1; force_static=1; use_dynamic=0
  else
    AC_MSG_ERROR([Unknown library file format: $PETSC_LIB_SNES])
  fi
  if test force_static -eq force_dynamic; then AC_MSG_ERROR([Mixing static and dynamic PETSc libraries]); fi
  search_petsc_lib_snes=0
else
  search_petsc_lib_snes=1
fi

dnl libpetscts.so(a)
AC_ARG_WITH(
  [PETSC_LIB_TS],
  [  --with-PETSC_LIB_TS             Full pathname to the libpetscts library
	Default: ${PETSC_DIR}/lib/${PETSC_ARCH}/libpetscts.so(a)],
  [PETSC_LIB_TS="${withval}"])
if test -n "$PETSC_LIB_TS"; then temp=`echo "$PETSC_LIB_TS" | grep "^/"`; else temp=""; fi
if test -n "$temp"; then
  temp=`ls $PETSC_LIB_TS`
  if test -z "$temp"; then AC_MSG_ERROR([File $PETSC_LIB_TS does not exist]); fi
  temp1=`ls $PETSC_LIB_TS | grep "\.so$"`
  temp2=`ls $PETSC_LIB_TS | grep "\.a$"`
  if test -n "$temp1"; then 
    use_static=0; use_dynamic=1; force_dynamic=1
  elif test -n "$temp2"; then
    use_static=1; force_static=1; use_dynamic=0
  else
    AC_MSG_ERROR([Unknown library file format: $PETSC_LIB_TS])
  fi
  if test force_static -eq force_dynamic; then AC_MSG_ERROR([Mixing static and dynamic PETSc libraries]); fi
  search_petsc_lib_ts=0
else
  search_petsc_lib_ts=1
fi

dnl libpetscvec.so(a)
AC_ARG_WITH(
  [PETSC_LIB_VEC],
  [  --with-PETSC_LIB_VEC            Full pathname to the libpetscvec library
	Default: ${PETSC_DIR}/lib/${PETSC_ARCH}/libpetscvec.so(a)],
  [PETSC_LIB_VEC="${withval}"])
if test -n "$PETSC_LIB_VEC"; then temp=`echo "$PETSC_LIB_VEC" | grep "^/"`; else temp=""; fi
if test -n "$temp"; then
  temp=`ls $PETSC_LIB_VEC`
  if test -z "$temp"; then AC_MSG_ERROR([File $PETSC_LIB_VEC does not exist]); fi
  temp1=`ls $PETSC_LIB_VEC | grep "\.so$"`
  temp2=`ls $PETSC_LIB_VEC | grep "\.a$"`
  if test -n "$temp1"; then 
    use_static=0; use_dynamic=1; force_dynamic=1
  elif test -n "$temp2"; then
    use_static=1; force_static=1; use_dynamic=0
  else
    AC_MSG_ERROR([Unknown library file format: $PETSC_LIB_VEC])
  fi
  if test force_static -eq force_dynamic; then AC_MSG_ERROR([Mixing static and dynamic PETSc libraries]); fi
  search_petsc_lib_vec=0
else
  search_petsc_lib_vec=1
fi

dnl For the remaining files, search for them in the usual locations
while true; do

  dnl Search for dynamic libraries
  if test $use_dynamic -eq 1; then
    is_complete_set=1
    dnl libpetsc.so
    if test $search_petsc_lib -eq 1; then 
      AC_PATH_PROGS([PETSC_LIB],[libpetsc.so],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB" -a $force_dynamic -eq 1; then 
        AC_MSG_ERROR([Unable to find libpetsc.so])
      elif test -z "$PETSC_LIB"; then
        AC_MSG_WARN([Unable to find libpetsc.so, trying static library search])
        use_static=1; force_static=1; use_dynamic=0; force_dynamic=0
      else
        PETSC_LIBDIR=`dirname $PETSC_LIB`
      fi
    fi
  fi
  if test $use_dynamic -eq 1; then
    dnl libpetsccontrib.so
    if test $search_petsc_lib_contrib -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_CONTRIB],[libpetsccontrib.so],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_CONTRIB"; then is_complete_set=0; fi
    fi
    dnl libpetscdm.so
    if test $search_petsc_lib_dm -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_DM],[libpetscdm.so],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_DM"; then is_complete_set=0; fi
    fi
    dnl libpetscksp.so
    if test $search_petsc_lib_ksp -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_KSP],[libpetscksp.so],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_KSP"; then is_complete_set=0; fi
    fi
    dnl libpetscmat.so
    if test $search_petsc_lib_mat -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_MAT],[libpetscmat.so],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_MAT"; then is_complete_set=0; fi
    fi
    dnl libpetscsnes.so
    if test $search_petsc_lib_snes -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_SNES],[libpetscsnes.so],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_SNES"; then is_complete_set=0; fi
    fi
    dnl libpetscts.so
    if test $search_petsc_lib_ts -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_TS],[libpetscts.so],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_TS"; then is_complete_set=0; fi
    fi
    dnl libpetscvec.so
    if test $search_petsc_lib_vec -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_VEC],[libpetscvec.so],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_VEC"; then is_complete_set=0; fi
    fi
    dnl Check for completeness and break or rerun search accordingly
    if test $is_complete_set -eq 1; then 
      break
    elif test $force_dynamic -eq 0; then
      AC_MSG_WARN([Unable to find a complete dynamic library set, trying static])
      use_static=1; force_static=1; use_dynamic=0; force_dynamic=0
    else
      AC_MSG_WARN([Unable to find a complete dynamic library set])
      break
    fi
  fi

  dnl Search for static libraries
  if test $use_static -eq 1; then
    is_complete_set=1
    dnl libpetsc.a
    if test $search_petsc_lib -eq 1; then 
      AC_PATH_PROGS([PETSC_LIB],[libpetsc.a],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB" -a $force_static -eq 1; then 
        AC_MSG_ERROR([Unable to find libpetsc.a])
      elif test -z "$PETSC_LIB"; then
        AC_MSG_WARN([Unable to find libpetsc.a, trying dynamic library search])
        use_dynamic=1; force_dynamic=1; use_static=0; force_static=0
      else
        PETSC_LIBDIR=`dirname $PETSC_LIB`
      fi
    fi
  fi
  if test $use_static -eq 1; then
    dnl libpetsccontrib.a
    if test $search_petsc_lib_contrib -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_CONTRIB],[libpetsccontrib.a],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_CONTRIB"; then is_complete_set=0; fi
    fi
    dnl libpetscdm.a
    if test $search_petsc_lib_dm -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_DM],[libpetscdm.a],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_DM"; then is_complete_set=0; fi
    fi
    dnl libpetscksp.a
    if test $search_petsc_lib_ksp -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_KSP],[libpetscksp.a],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_KSP"; then is_complete_set=0; fi
    fi
    dnl libpetscmat.a
    if test $search_petsc_lib_mat -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_MAT],[libpetscmat.a],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_MAT"; then is_complete_set=0; fi
    fi
    dnl libpetscsnes.a
    if test $search_petsc_lib_snes -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_SNES],[libpetscsnes.a],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_SNES"; then is_complete_set=0; fi
    fi
    dnl libpetscts.a
    if test $search_petsc_lib_ts -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_TS],[libpetscts.a],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_TS"; then is_complete_set=0; fi
    fi
    dnl libpetscvec.a
    if test $search_petsc_lib_vec -eq 1; then
      AC_PATH_PROGS([PETSC_LIB_VEC],[libpetscvec.a],[],[$PETSC_LIBDIR_PATH])
      if test -z "$PETSC_LIB_VEC"; then is_complete_set=0; fi
    fi
    dnl Check for completeness and break or rerun search accordingly
    if test $is_complete_set -eq 1; then 
      break
    elif test $force_static -eq 0; then
      AC_MSG_WARN([Unable to find a complete static library set, trying dynamic])
      use_dynamic=1; force_dynamic=1; use_static=0; force_static=0
    else
      AC_MSG_WARN([Unable to find a complete static library set])
      break
    fi
  fi

done

dnl Define PETSC_LIBS for single variable substitution

PETSC_LIBS=$PETSC_LIB_CONTRIB" "$PETSC_LIB_DM" "$PETSC_LIB_KSP" "$PETSC_LIB_MAT" "$PETSC_LIB_SNES" "$PETSC_LIB_TS" "$PETSC_LIB_VEC" "$PETSC_LIB

dnl Set information variable values
if test $use_dynamic -eq 1; then 
  PETSC_LIB_TYPE="dynamic"
elif test $use_static -eq 1; then
  PETSC_LIB_TYPE="static"
else 
  PETSC_LIB_TYPE="error"
fi

if test $is_complete_set -eq 1; then
  PETSC_LIB_STATUS="complete"
else
  PETSC_LIB_STATUS="incomplete"
fi

dnl ----------------------------------------------------------------------
dnl Export discovered variables, and confirm finding of PETSc
dnl ----------------------------------------------------------------------

AC_SUBST([PETSC_DIR])
AC_SUBST([PETSC_ARCH])

AC_SUBST([PETSC_INCDIR])
AC_SUBST([PETSC_INCDIR_ARCH])

AC_SUBST([PETSC_LIBDIR])
AC_SUBST([PETSC_LIB_TYPE])
AC_SUBST([PETSC_LIB_STATUS])

AC_SUBST([PETSC_LIB])
AC_SUBST([PETSC_LIB_CONTRIB])
AC_SUBST([PETSC_LIB_DM])
AC_SUBST([PETSC_LIB_KSP])
AC_SUBST([PETSC_LIB_MAT])
AC_SUBST([PETSC_LIB_SNES])
AC_SUBST([PETSC_LIB_TS])
AC_SUBST([PETSC_LIB_VEC])

AC_SUBST([PETSC_INC])
AC_SUBST([PETSC_LIBS])

AC_DEFINE([HAVE_PETSC],[],[Defined if PETSc was successfully found])

dnl ----------------------------------------------------------------------
dnl Write to summary file if it was defined
dnl ----------------------------------------------------------------------

if test -n "$config_summary_file"; then
  echo " Using PETSc package:"				>> $config_summary_file
  echo "  Basic variables:"				>> $config_summary_file
  echo "   PETSC_DIR:            $PETSC_DIR"		>> $config_summary_file
  echo "   PETSC_ARCH:           $PETSC_ARCH"		>> $config_summary_file
  echo "  Include paths:"				>> $config_summary_file
  echo "   PETSC_INCDIR:         $PETSC_INCDIR"		>> $config_summary_file
  echo "   PETSC_INCDIR_ARCH:    $PETSC_INCDIR_ARCH"	>> $config_summary_file
  echo "  Library status:"				>> $config_summary_file
  echo "   PETSC_LIBDIR:         $PETSC_LIBDIR"		>> $config_summary_file
  echo "   PETSC_LIB_TYPE:       $PETSC_LIB_TYPE"	>> $config_summary_file
  echo "   PETSC_LIB_STATUS:     $PETSC_LIB_STATUS"	>> $config_summary_file
  echo "  Library paths:"				>> $config_summary_file
  echo "   PETSC_LIB             $PETSC_LIB"		>> $config_summary_file
  echo "   PETSC_LIB_CONTRIB:    $PETSC_LIB_CONTRIB"	>> $config_summary_file
  echo "   PETSC_LIB_DM:         $PETSC_LIB_DM"		>> $config_summary_file
  echo "   PETSC_LIB_KSP:        $PETSC_LIB_KSP"	>> $config_summary_file
  echo "   PETSC_LIB_MAT:        $PETSC_LIB_MAT"	>> $config_summary_file
  echo "   PETSC_LIB_SNES:       $PETSC_LIB_SNES"	>> $config_summary_file
  echo "   PETSC_LIB_TS:         $PETSC_LIB_TS"		>> $config_summary_file
  echo "   PETSC_LIB_VEC:        $PETSC_LIB_VEC"	>> $config_summary_file
  echo ""						>> $config_summary_file
fi
