dnl ######################################################################
dnl
dnl File:	vorpal.m4
dnl
dnl Purpose:	Check for VORPAL defines, including VDIM and
dnl		MAX_PARTICLE_GROUP_SIZE
dnl
dnl Version: $Id: vorpal.m4 2148 2007-01-15 23:19:38Z dws $
dnl
dnl Tech-X configure system
dnl
dnl ######################################################################

dnl ######################################################################
dnl
dnl Check for VDIM=9
dnl
dnl ######################################################################

AC_ARG_WITH(vdim,[  --with-vdim=<value of VDIM>     set max # of non spatial particle variables], VDIM="$withval",VDIM="")
AC_MSG_CHECKING(values of VDIM)

# Extract the vdim values
# echo VDIM = \'$VDIM\'
if test -n "$VDIM"; then
  vdimvals=`echo $VDIM | sed 's/,/ /g'`
else
  vdimvals="3 4 5 9"
fi
# echo vdimvals = $vdimvals

vdimmax=3
for i in $vdimvals; do
  if test $i -gt $vdimmax; then vdimmax=$i; fi
  case $i in
    1)
      AC_DEFINE([VDIM1], 1, [Define if have VDIM=1 particles])
      ;;
    2)
      AC_DEFINE([VDIM2], 1, [Define if have VDIM=2 particles])
      ;;
    3)
      AC_DEFINE([VDIM3], 1, [Define if have VDIM=3 particles])
      ;;
    4)
      AC_DEFINE([VDIM4], 1, [Define if have VDIM=4 particles])
      ;;
    5)
      AC_DEFINE([VDIM5], 1, [Define if have VDIM=5 particles])
      ;;
    9)
      AC_DEFINE(VDIM9, 1, [Define if have VDIM=9 particles])
      AC_DEFINE([HAVE_VAR_DT_PTCLS], 1,
	[Define if have variable time step particles])
      VPVARDT_LIBFLAG="-L../vpvardt -lvpvardt"
      ;;
    10)
      AC_DEFINE([VDIM10], 1, [Define if have VDIM=10 particles])
      ;;
    *)
      AC_MSG_ERROR(VDIM set to invalid value of $i. Currently must set to 1, 2, 3, 4, 5 or 9.)
      ;;
  esac
done
AC_MSG_RESULT($vdimvals)
AC_SUBST(VPVARDT_LIBFLAG)
AC_DEFINE_UNQUOTED([VDIMMAX], ${vdimmax},
	[Define maximum allowed value of VDIM])
if test -n "$config_summary_file"; then
  echo Building with ${vdimmax} maximum internal particle variables \
	>> $config_summary_file
  echo >> $config_summary_file
fi

# Get the maximum particle group size
AC_MSG_CHECKING(maximum size of a particle group)
AC_ARG_WITH(max-ptcl-grp-size,
	AC_HELP_STRING([----with-max-ptcl-grp-size=<value of MAX_PARTICLE_GROUP_SIZE>],
        [set max size of a particle group]),
	MAX_PARTICLE_GROUP_SIZE=$withval,
	MAX_PARTICLE_GROUP_SIZE=1024)
AC_DEFINE_UNQUOTED([MAX_PARTICLE_GROUP_SIZE], $MAX_PARTICLE_GROUP_SIZE,
[Define the maximum size of a particle group])
AC_MSG_RESULT($MAX_PARTICLE_GROUP_SIZE)

if test "$HDF5_INCDIR" = "$HDF5_INCDIR_SERIAL"; then
    VPDATANAL_CXX=$CXX
else
    VPDATANAL_CXX=$SERIALCXX
fi

AC_SUBST(VPDATANAL_CXX)

