dnl ######################################################################
dnl
dnl Check for XERCES xml parser stuff
dnl
dnl    COMPDIR must have already been defined (by flags.m4)
dnl
dnl ######################################################################

dnl ######################################################################
dnl
dnl Get the XERCES XML parser include files
dnl
dnl ######################################################################

AC_ARG_WITH(xerces-incdir,
[  --with-xerces-incdir=<xerces-include-dir>      to set location of the XERCES include directory],
XERCES_INCDIR="$withval")

dnl
dnl If not known, check in typical directories
dnl
if test -n "$XERCES_INCDIR"; then
  XERCES_IDR_PATH=$XERCES_INCDIR
else
  XERCES_IDR_PATH=$HOME/$host/xerces-${COMPDIR}/include:$HOME/$host/xerces/include:/usr/local/xerces-${COMPDIR}/include:/usr/local/xerces/include:/loc/xerces-${COMPDIR}/include:/loc/xerces/include:/mfe/local/xerces-${COMPDIR}/include:/mfe/local/xerces/include
fi
AC_PATH_PROGS(ABS_XERCES_INCDIR, xercesc/util/XercesVersion.hpp, "", $XERCES_IDR_PATH)

if test -z "$ABS_XERCES_INCDIR"; then
  AC_MSG_WARN(XERCES includes not found in $XERCES_IDR_PATH.  Use --with-xerces-incdir to set the location of xercesc/util/XercesVersion.hpp. ELVIS server will not run with Xerces.)
  XERCES_INCDIR=.
else
  isVersion2=`grep "XERCES_VERSION_MAJOR 2" $ABS_XERCES_INCDIR`
  if test -n "$isVersion2"; then
    AC_DEFINE(HAVE_XERCES, , Define if xerces is present)
    XERCES_INCDIR1=`dirname $ABS_XERCES_INCDIR`
    XERCES_INCDIR=`dirname $XERCES_INCDIR1`
    XERCES_INCDIR=`dirname $XERCES_INCDIR`
    echo XERCES include directory is $XERCES_INCDIR
  else
    AC_MSG_WARN(Incorrect Xerces version.  Expect version 2.x.   ELVIS server will not run with Xerces.)
  fi

dnl ######################################################################
dnl
dnl Determine the correct XERCES library, if include dir is found
dnl
dnl ######################################################################

  AC_ARG_WITH(XERCES_LIBDIR,
  [  --with-XERCES_LIBDIR=<xerces libdir>      to set location of xerces libraries], XERCES_LIBDIR="$withval")

  if test -n "$XERCES_LIBDIR"; then
    XERCES_LIB_PATH=$XERCES_LIBDIR
  else
    XERCES_LIB_PATH=$HOME/$host/xerces-${COMPDIR}/lib:$HOME/$host/xerces/lib/$COMPDIR:/usr/local/xerces-${COMPDIR}/lib:/usr/local/xerces/lib:/loc/xerces-${COMPDIR}/lib:/loc/xerces/lib/$COMPDIR:/mfe/local/xerces-${COMPDIR}/lib:/mfe/local/xerces/lib/$COMPDIR
  fi
  AC_PATH_PROGS(ABS_XERCES_LIB, libxerces-c.so, "", $XERCES_LIB_PATH)
  if test -z "$ABS_XERCES_LIB"; then
    AC_MSG_WARN(Unable to find libxerces-c.so in $XERCES_LIB_PATH.  Set the appropriate directory using --with-XERCES_LIBDIR. ELVIS server will not run with Xerces.)
    XERCES_LIBDIR=""
  else
    XERCES_LIBDIR=`dirname $ABS_XERCES_LIB`
    XERCES_LIB="-L$XERCES_LIBDIR -lxerces-c"
  fi

fi
if test -z "$XERCES_LIBDIR"; then XERCES_LIBDIR=.; fi
AC_SUBST(XERCES_LIBDIR)
AC_SUBST(XERCES_LIB)
AC_SUBST(XERCES_INCDIR)


